/*
 \verbatim

    This file is part of CSSEngine. CSSEng is a CSS (Cascaded Style Sheet)
    parsing and selecting engine derived from libcss of NetSurf project.

    Licensed under the MIT License,

           http://www.opensource.org/licenses/mit-license.php

    Copyright 2008 John-Mark Bell <jmb@netsurf-browser.org>
    Copyright (C) 2021 ~ 2023 Beijing FMSoft Technologies Co., Ltd.

 \endverbatim
 */

/*
 * This file was generated by CSSEng gen_parser 
 * 
 * Generated from:
 *
 * line_break:CSS_PROP_LINE_BREAK IDENT:( INHERIT: AUTO:0,LINE_BREAK_AUTO LOOSE:0,LINE_BREAK_LOOSE NORMAL:0,LINE_BREAK_NORMAL STRICT:0,LINE_BREAK_STRICT ANYWHERE:0,LINE_BREAK_ANYWHERE IDENT:)
 * 
 * Copyright (C) 2021, 2023 Beijing FMSoft Technologies Co., Ltd.
 */

#include <assert.h>
#include <string.h>

#include "bytecode/bytecode.h"
#include "bytecode/opcodes.h"
#include "parse/properties/properties.h"
#include "parse/properties/utils.h"

/**
 * Parse line_break
 *
 * \param c      Parsing context
 * \param vector  Vector of tokens to process
 * \param ctx      Pointer to vector iteration context
 * \param result  resulting style
 * \return CSS_OK on success,
 *       CSS_NOMEM on memory exhaustion,
 *       CSS_INVALID if the input is not valid
 *
 * Post condition: \a *ctx is updated with the next token to process
 *           If the input is invalid, then \a *ctx remains unchanged.
 */
css_error css__parse_line_break(css_language *c,
        const parserutils_vector *vector, int *ctx,
        css_style *result)
{
    int orig_ctx = *ctx;
    css_error error;
    const css_token *token;
    bool match;

    token = parserutils_vector_iterate(vector, ctx);
    if ((token == NULL) || ((token->type != CSS_TOKEN_IDENT))) {
		*ctx = orig_ctx;
		return CSS_INVALID;
	}

	if ((lwc_string_caseless_isequal(token->idata, c->strings[INHERIT], &match) == lwc_error_ok && match)) {
			error = css_stylesheet_style_inherit(result, CSS_PROP_LINE_BREAK);
	} else if ((lwc_string_caseless_isequal(token->idata, c->strings[AUTO], &match) == lwc_error_ok && match)) {
			error = css__stylesheet_style_appendOPV(result, CSS_PROP_LINE_BREAK, 0,LINE_BREAK_AUTO);
	} else if ((lwc_string_caseless_isequal(token->idata, c->strings[LOOSE], &match) == lwc_error_ok && match)) {
			error = css__stylesheet_style_appendOPV(result, CSS_PROP_LINE_BREAK, 0,LINE_BREAK_LOOSE);
	} else if ((lwc_string_caseless_isequal(token->idata, c->strings[NORMAL], &match) == lwc_error_ok && match)) {
			error = css__stylesheet_style_appendOPV(result, CSS_PROP_LINE_BREAK, 0,LINE_BREAK_NORMAL);
	} else if ((lwc_string_caseless_isequal(token->idata, c->strings[STRICT], &match) == lwc_error_ok && match)) {
			error = css__stylesheet_style_appendOPV(result, CSS_PROP_LINE_BREAK, 0,LINE_BREAK_STRICT);
	} else if ((lwc_string_caseless_isequal(token->idata, c->strings[ANYWHERE], &match) == lwc_error_ok && match)) {
			error = css__stylesheet_style_appendOPV(result, CSS_PROP_LINE_BREAK, 0,LINE_BREAK_ANYWHERE);
	} else {
		error = CSS_INVALID;
	}

    if (error != CSS_OK)
        *ctx = orig_ctx;
    
    return error;
}

